@@ -1,13 +1,11 @@
-# Author: Nicola Larosa
-# Contact: docutils@tekNico.net
-# Revision: $Revision: 1.3 $
-# Date: $Date: 2003/06/26 18:32:02 $
+# $Id: it.py 9030 2022-03-05 23:28:32Z milde $
+# Author: Nicola Larosa <docutils@tekNico.net>
 # Copyright: This module has been placed in the public domain.
 
 # New language mappings are welcome.  Before doing a new translation, please
-# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
-# translated for each language: one in docutils/languages, the other in
-# docutils/parsers/rst/languages.
+# read <https://docutils.sourceforge.io/docs/howto/i18n.html>.
+# Two files must be translated for each language: one in docutils/languages,
+# the other in docutils/parsers/rst/languages.
 
 """
 Italian-language mappings for language-dependent features of Docutils.
@@ -45,7 +43,7 @@ bibliographic_fields = {
       'autori': 'authors',
       'organizzazione': 'organization',
       'indirizzo': 'address',
-      'contatti': 'contact',
+      'contatto': 'contact',
       'versione': 'version',
       'revisione': 'revision',
       'status': 'status',
